@@ -19,7 +19,6 @@ import validators
 from urllib.parse import urljoin
 from urllib.parse import urlsplit
 from aiohttp import ClientSession
-import async_timeout
 
 
 
@@ -107,7 +106,7 @@ async def fetch(client,url):
         return await resp.text()
 
 #############################VIPER API CALLS ################    
-async def tcp_echo_clientviper(message, loop,host,port,microserviceid,timeout=180):
+async def tcp_echo_clientviper(message, loop,host,port,microserviceid):
 
     hostarr=host.split(":")
     hbuf=hostarr[0]
@@ -124,8 +123,7 @@ async def tcp_echo_clientviper(message, loop,host,port,microserviceid,timeout=18
     geturl=formaturlviper(message,host,microserviceid,hbuf,port) #host contains http:// or https://
     message="%s" % geturl 
 
-    with async_timeout.timeout(timeout):
-      async with ClientSession() as session:
+    async with ClientSession() as session:
         html = await fetch(session,message)
         return html
 
@@ -161,16 +159,6 @@ def vipersubscribeconsumer(vipertoken,host,port,topic,companyname,contactname,co
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperdeletetopics(vipertoken,host,port,topic,microserviceid=''):
-
-    if len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0:
-         return "Please enter host,port,vipertoken,topic"
-        
-    value=("deletetopics?vipertoken="+vipertoken + "&topic="+topic)
-    loop = asyncio.get_event_loop()
-    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
-    return val
-
 def viperunsubscribeconsumer(vipertoken,host,port,consumerid,brokerhost='',brokerport=-999,microserviceid=''):
 
     if len(vipertoken)==0 or len(consumerid)==0 or len(host)==0:
@@ -203,26 +191,24 @@ def viperconsumefromtopic(vipertoken,host,port,topic,consumerid,companyname,part
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,inputdata,algokey='',partition=-1,offset=-1,
-                     enabletls=1,delay=1000,hpdeport=-999,brokerhost='',brokerport=9092,
+def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,enabletls=0,delay=0,hpdeport=-999,brokerhost='',brokerport=9092,
                      timeout=120,usedeploy=0,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
     
-    if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(inputdata)==0 or len(produceto)==0 or len(companyname)==0 or len(consumerid)==0
+    if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(produceto)==0 or len(companyname)==0 or len(consumerid)==0
                  or len(producerid)==0 or len(hpdehost)==0 or hpdeport==-999):
-         return "Please enter host,port,vipertoken,consumefrom,inputdata,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
+         return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdepredict?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&delay=" + str(delay) + "&inputdata="+ inputdata + "&algokey="+algokey + "&partition="+str(partition)+"&offset="+str(offset)+ "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&usedeploy=" +str(usedeploy) +"&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
+           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&usedeploy=" +str(usedeploy) +"&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,partition=-1,offset=-1,
-                      enabletls=1,delay=1000,hpdeport=-999,usedeploy=0,
+def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,enabletls=0,delay=100,hpdeport=-999,usedeploy=0,
                       ismin=1,constraints='best',stretchbounds=20,constrainttype=1,epsilon=10,brokerhost='',brokerport=9092,
-                      timeout=120,microserviceid=''):
+                     timeout=120,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
     
@@ -231,15 +217,12 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
          return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdeoptimize?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-         "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&companyname="+companyname +
-         "&partition="+str(partition)+"&offset="+str(offset)+
-         "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport))
+         "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport))
     loop = asyncio.get_event_loop()
-    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
+    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,viperconfigfile,
-                      enabletls=1,partition=-1,modelruns=50,hpdeport=-999,offset=-1,islogistic=0,
+def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport=-999,offset=0,islogistic=0,
                       brokerhost='',brokerport=9092,timeout=120,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
@@ -249,109 +232,42 @@ def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,con
          return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdetraining?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&producerid="+producerid + "&companyname="+companyname + "&partition="+str(partition)+"&modelruns="+str(modelruns) +"&hpdehost=" +hpdehost +
-           "&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+ "&offset="+str(offset) + "&viperconfigfile="+viperconfigfile +
-           "&brokerport="+str(brokerport)+"&enabletls="+str(enabletls) + "&islogistic=" + str(islogistic) + "&timeout="+str(timeout) )
+           "&producerid="+producerid + "&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+
+           "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
-#    future = asyncio.wait_for(loop.run_in_executor(None, time.sleep, 2), timeout)
-#    try:
-    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
- #   except Exception as e:
-  #     print(e) 
+    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperanomalytrain(vipertoken,host,port,consumefrom,produceto,producepeergroupto,produceridpeergroup,consumeridproduceto,
-                      streamstoanalyse,
-                      companyname,consumerid,producerid,flags,hpdehost,viperconfigfile,
-                      enabletls=1,partition=-1,hpdeport=-999,
-                      brokerhost='',brokerport=9092,delay=1000,timeout=120,microserviceid=''):
-
-    #reads the fieldnames and gets latest data from each stream (or fieldname)
-    
-    if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(produceto)==0 or len(companyname)==0 or len(consumerid)==0
-                 or len(producerid)==0 or len(hpdehost)==0 or hpdeport==-999 or len(streamstoanalyse)==0 or len(producepeergroupto)==0
-                 or len(produceridpeergroup)==0 or len(consumeridproduceto)==0 or len(flags)==0):
-         return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,streamstoanalyse,consumeridproduceto,flags,consumerid,producepeergroupto,produceridpeergroup,producerid,hpdehost,hpdeport"
-        
-    value=("viperanomalytrain?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&producepeergroupto=" + producepeergroupto + "&produceridpeergroup=" + produceridpeergroup + "&consumeridproduceto="+consumeridproduceto +
-           "&streamstoanalyse="+streamstoanalyse + "&flags="+flags + "&delay=" +str(delay) + "&timeout=" + str(timeout) +
-           "&producerid="+producerid + "&companyname="+companyname + "&partition="+str(partition) +"&hpdehost=" +hpdehost +
-           "&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&viperconfigfile="+viperconfigfile +
-           "&brokerport="+str(brokerport)+"&enabletls="+str(enabletls))
-    loop = asyncio.get_event_loop()
-#    future = asyncio.wait_for(loop.run_in_executor(None, time.sleep, 2), timeout)
-#    try:
-    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
- #   except Exception as e:
-  #     print(e) 
-    return val
-
-#http://192.168.0.13:8000/viperanomalypredict?consumefrom=anomalypeergroup&produceto=anomalydataresults&consumeinputstream=joined-viper-test11
-#&produceinputstreamtest=inputstreamdata&produceridinputstreamtest=ProducerId-l6hVEHUATxLrhSPT3aeVztPpr035oc&
-#streamstoanalyse=viperdependentvariable,viperindependentvariable1,viperindependentvariable2&
-#vipertoken=hivmg1TMR1zS1ZHVqF4s83Zq1rDtsZKh9pEULHnLR0BXPlaPEMZBEAyC7TY0&companyname=OTICS test&
-#consumerid=ConsumerId-irbcZ5iGigW51bVD2Z1K0E2WsN9RuV&consumeridinputstream=ConsumerId-lehi50iuYXd1asafvQYyOd1b4Okrqa&
-#producerid=ProducerId-haubDasU6pt8a6nyZ2BQAl1rXblm-p&enabletls=1&delay=10000&partition=-1&hpdehost=http://192.168.0.13&hpdeport=8001&viperconfigfile=viper.env&
-#flags=riskscore=.8~complete=and~type=or,topic=viperdependentvariable,topictype=numeric,sc>1500~type=and,topic=viperindependentvariable1,topictype=numeric,v1<100,sc>200~type=or,topic=accountname3,topictype=string,stringcontains=1,v2=Failed Record^Failed Record^test record,sc>120~type=or,topic=viperindependentvariable2,topictype=numeric,v1<100,sc>2000
-
-def viperanomalypredict(vipertoken,host,port,consumefrom,produceto,consumeinputstream,produceinputstreamtest,produceridinputstreamtest,
-                      streamstoanalyse,consumeridinputstream,
-                      companyname,consumerid,producerid,flags,hpdehost,viperconfigfile,
-                      enabletls=1,partition=-1,hpdeport=-999,
-                      brokerhost='',brokerport=9092,delay=1000,timeout=120,microserviceid=''):
-
-    #reads the fieldnames and gets latest data from each stream (or fieldname)
-    
-    if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(produceto)==0 or len(companyname)==0 or len(consumerid)==0
-                 or len(producerid)==0 or len(hpdehost)==0 or hpdeport==-999 or len(streamstoanalyse)==0 or len(produceinputstreamtest)==0
-                 or len(produceridinputstreamtest)==0 or len(consumeridinputstream)==0 or len(flags)==0):
-         return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,streamstoanalyse,produceinputstreamtest,produceridinputstreamtest,consumeridinputstream,flags,consumerid,producerid,hpdehost,hpdeport"
-        
-    value=("viperanomalypredict?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&produceinputstreamtest="+produceinputstreamtest + "&produceridinputstreamtest="+produceridinputstreamtest + "&consumeridinputstream="+consumeridinputstream+
-           "&streamstoanalyse="+streamstoanalyse + "&flags="+flags + "&delay=" +str(delay) + "&timeout=" + str(timeout) +
-           "&producerid="+producerid + "&companyname="+companyname + "&partition="+str(partition) +"&hpdehost=" +hpdehost +
-           "&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&viperconfigfile="+viperconfigfile +
-           "&brokerport="+str(brokerport)+"&enabletls="+str(enabletls))
-    loop = asyncio.get_event_loop()
-#    future = asyncio.wait_for(loop.run_in_executor(None, time.sleep, 2), timeout)
-#    try:
-    val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid,timeout))
- #   except Exception as e:
-  #     print(e) 
-    return val
-
-def viperproducetotopicstream(vipertoken,host,port,topic,producerid,offset,maxrows=0,enabletls=0,delay=100,brokerhost='',brokerport=-999,microserviceid=''):
+def viperproducetotopicstream(vipertoken,host,port,topic,producerid,offset,enabletls=0,delay=100,brokerhost='',brokerport=-999,microserviceid=''):
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0 or len(producerid)==0):
          return "Please enter host,port,vipertoken,topic,producerid"
         
-    value=("producetotopicstream?vipertoken="+vipertoken + "&topicname="+topic + "&delay=" + str(delay) + "&maxrows=" +str(maxrows) + "&enabletls="+str(enabletls) +"&brokerhost="+brokerhost + "&brokerport="+str(brokerport) + "&producerid="+producerid + "&offset="+str(offset))
+    value=("producetotopicstream?vipertoken="+vipertoken + "&topicname="+topic + "&delay=" + str(delay) + "&enabletls="+str(enabletls) +"&brokerhost="+brokerhost + "&brokerport="+str(brokerport) + "&producerid="+producerid + "&offset="+str(offset))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
 def vipercreatetrainingdata(vipertoken,host,port,consumefrom,produceto,dependentvariable,independentvariables,
-                            consumerid,producerid,companyname,partition=-1,enabletls=0,delay=100,brokerhost='',brokerport=-999,microserviceid=''):
+                            consumerid,producerid,offset,companyname,enabletls=0,delay=100,maxrows=-1,brokerhost='',brokerport=-999,microserviceid=''):
 
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(produceto)==0 or len(dependentvariable)==0 or
         len(independentvariables)==0 or len(companyname)==0 or len(consumerid)==0 or len(producerid)==0):
          return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid"
         
     value=("createtrainingdata?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto="+produceto +
-           "&dependentvariable="+dependentvariable+"&independentvariables="+independentvariables +
-           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&partition="+str(partition)+"&consumerid="+consumerid + "&producerid="+producerid+"&companyname="+companyname + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
+           "&dependentvariable="+dependentvariable+"&independentvariables="+independentvariables +"&offset="+str(offset)+
+           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&consumerid="+consumerid + "&producerid="+producerid+"&companyname="+companyname + "&maxrows="+str(maxrows) + "&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def vipercreatetopic(vipertoken,host,port,topic,companyname,contactname,contactemail,location,description,enabletls=0,brokerhost='',brokerport=-999,numpartitions=1,replication=1,microserviceid=''):
+def vipercreatetopic(vipertoken,host,port,topic,companyname,contactname,contactemail,location,description,brokerhost='',brokerport=-999,numpartitions=1,replication=1,microserviceid=''):
 
     if len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0 or len(companyname)==0 or len(contactname)==0 or len(contactemail)==0 or len(location)==0 or len(description)==0:
          return "Please enter host,port,vipertoken,topic, companyname,contactname,contactemail,location and description"
         
     value=("createtopics?vipertoken="+vipertoken + "&topic="+topic + "&companyname=" + companyname + "&contactname="+contactname +
-           "&contactemail="+contactemail + "&location="+location+"&description="+description+ "&enabletls="+str(enabletls) + "&numpartitions="+str(numpartitions)+
+           "&contactemail="+contactemail + "&location="+location+"&description="+description+"&numpartitions="+str(numpartitions)+
            "&replicationfactor="+str(replication) + "&brokerhost="+brokerhost + "&brokerport=" + str(brokerport) )
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
@@ -383,19 +299,19 @@ def vipercreatejointopicstreams(vipertoken,host,port,topic,topicstojoin,companyn
     return val
 
 def vipercreateconsumergroup(vipertoken,host,port,topic,groupname,companyname,contactname,contactemail,description,
-                                location,enabletls=1,brokerhost='',brokerport=-999,microserviceid=''):
+                                location,brokerhost='',brokerport=-999,microserviceid=''):
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(contactname)==0 or len(contactemail)==0 or len(description)==0 or
         len(location)==0 or len(groupname)==0):
          return "Please enter host,port,vipertoken,contactname,contactemail,companyname,description,location,groupname"
         
     value=("createconsumergroup?vipertoken="+vipertoken + "&topic="+topic + "&groupname="+groupname +
-           "&companyname="+companyname+"&contactname="+contactname +"&contactemail="+contactemail+ "&enabletls="+str(enabletls)+
+           "&companyname="+companyname+"&contactname="+contactname +"&contactemail="+contactemail+
            "&description="+description + "&location="+location+"&brokerhost="+brokerhost+"&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperconsumergroupconsumefromtopic(vipertoken,host,port,topic,consumerid,groupid,companyname,partition=-1,enabletls=1,delay=1000,offset=-1,brokerhost='',brokerport=-999,microserviceid=''):
+def viperconsumergroupconsumefromtopic(vipertoken,host,port,topic,consumerid,groupid,companyname,partition=-1,enabletls=0,delay=100,offset=0,brokerhost='',brokerport=-999,microserviceid=''):
     if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(companyname)==0 or len(consumerid)==0 or len(groupid)==0):
          return "Please enter host,port,vipertoken,consumerid,companyname,groupid"
         
